summaryrefslogtreecommitdiff
path: root/src/common/mmo.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/common/mmo.h')
-rw-r--r--src/common/mmo.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/src/common/mmo.h b/src/common/mmo.h
index 4284e7f72..744108a31 100644
--- a/src/common/mmo.h
+++ b/src/common/mmo.h
@@ -545,7 +545,7 @@ enum { //Change Guild Infos
GBI_EXP =1, // Guild Experience (EXP)
GBI_GUILDLV, // Guild level
GBI_SKILLPOINT, // Guild skillpoints
- GBI_SKILLLV, // Guild skilllv ?? seem unused
+ GBI_skill_lv, // Guild skill_lv ?? seem unused
};
enum { //Change Member Infos